@@ -3,7 +3,7 @@
 * configure.py to determine the compilers version number.
 */
 
-#if defined(_MSC_VER)
+#if defined(_MSC_VER) and !defined(__clang__)
 
 /*
    _MSC_VER Defined as an integer literal that encodes the major and
@@ -35,7 +35,9 @@ EMCC __EMSCRIPTEN_major__ __EMSCRIPTEN_minor__
 * __apple_build_version__ to 15000309
 */
 
-   #if __apple_build_version__ >= 15000300
+   #if __apple_build_version__ >= 16000000
+XCODE 16 0
+   #elif __apple_build_version__ >= 15000300
 XCODE 15 3
    #elif __apple_build_version__ >= 15000000
 XCODE 15 0
